pub struct CallResponse {
    pub result: Value,
    pub idempotent: bool,
}
CallResponse : CallResponse contains the result of a /call invocation.

Fields

result: Value

Result contains the result of the /call invocation. This result will not be inspected or interpreted by Rosetta tooling and is left to the caller to decode.

idempotent: bool

Idempotent indicates that if /call is invoked with the same CallRequest again, at any point in time, it will return the same CallResponse. Integrators may cache the CallResponse if this is set to true to avoid making unnecessary calls to the Rosetta implementation. For this reason, implementers should be very conservative about returning true here or they could cause issues for the caller.

Implementations

source

impl CallResponse

source

pub fn new(result: Value, idempotent: bool) -> CallResponse

CallResponse contains the result of a /call invocation.