Enum rosetta_types::case::Case
source · pub enum Case {
UpperCase,
LowerCase,
CaseSensitive,
Null,
}Expand description
Case : Case specifies the expected case for strings and hashes. Case specifies the expected case for strings and hashes.
Variants