pub struct ConstructionMetadataRequest {
pub network_identifier: NetworkIdentifier,
pub options: Option<Value>,
pub public_keys: Vec<PublicKey>,
}Expand description
ConstructionMetadataRequest : A ConstructionMetadataRequest is utilized to get information required to construct a transaction. The Options object used to specify which metadata to return is left purposely unstructured to allow flexibility for implementers. Options is not required in the case that there is network-wide metadata of interest.
Fields
network_identifier: NetworkIdentifieroptions: Option<Value>Some blockchains require different metadata for different types of transaction construction (ex: delegation versus a transfer). Instead of requiring a blockchain node to return all possible types of metadata for construction (which may require multiple node fetches), the client can populate an options object to limit the metadata returned to only the subset required.
public_keys: Vec<PublicKey>Implementations
Sourceimpl ConstructionMetadataRequest
impl ConstructionMetadataRequest
Sourcepub fn new(network_identifier: NetworkIdentifier) -> ConstructionMetadataRequest
pub fn new(network_identifier: NetworkIdentifier) -> ConstructionMetadataRequest
A ConstructionMetadataRequest is utilized to get information required to construct a transaction. The Options object used to specify which metadata to return is left purposely unstructured to allow flexibility for implementers. Options is not required in the case that there is network-wide metadata of interest.