Module construction_parse_response

Module construction_parse_response 

Structs

ConstructionParseResponse
ConstructionParseResponse : ConstructionParseResponse contains an array of operations that occur in a transaction blob. This should match the array of operations provided to /construction/preprocess and /construction/payloads.