Enum rosetta_types::operator::Operator
source · pub enum Operator {
Or,
And,
}Expand description
Operator : Operator is used by query-related endpoints to determine how to apply conditions. If this field is not populated, the default and value will be used.
Operator is used by query-related endpoints to determine how to apply conditions. If this field is not populated, the default and value will be used.
Variants