pub struct PartialBlockIdentifier {
pub index: Option<u64>,
pub hash: Option<String>,
}Expand description
PartialBlockIdentifier : When fetching data by BlockIdentifier, it may be possible to only specify the index or hash. If neither property is specified, it is assumed that the client is making a request at the current block.
Fields
index: Option<u64>hash: Option<String>Implementations
sourceimpl PartialBlockIdentifier
impl PartialBlockIdentifier
sourcepub fn new() -> PartialBlockIdentifier
pub fn new() -> PartialBlockIdentifier
When fetching data by BlockIdentifier, it may be possible to only specify the index or hash. If neither property is specified, it is assumed that the client is making a request at the current block.