Struct rosetta_types::transaction::Transaction
source · pub struct Transaction {
pub transaction_identifier: TransactionIdentifier,
pub operations: Vec<Operation>,
pub related_transactions: Option<Vec<RelatedTransaction>>,
pub metadata: Option<Value>,
}Expand description
Transaction : Transactions contain an array of Operations that are attributable to the same TransactionIdentifier.
Fields
transaction_identifier: TransactionIdentifieroperations: Vec<Operation>metadata: Option<Value>Transactions that are related to other transactions (like a cross-shard transaction) should include the tranaction_identifier of these transactions in the metadata.
Implementations
sourceimpl Transaction
impl Transaction
sourcepub fn new(
transaction_identifier: TransactionIdentifier,
operations: Vec<Operation>
) -> Transaction
pub fn new( transaction_identifier: TransactionIdentifier, operations: Vec<Operation> ) -> Transaction
Transactions contain an array of Operations that are attributable to the same TransactionIdentifier.