Struct rosetta_types::version::Version
source · pub struct Version {
pub rosetta_version: String,
pub node_version: String,
pub middleware_version: Option<String>,
pub metadata: Option<Value>,
}Expand description
Version : The Version object is utilized to inform the client of the versions of different components of the Rosetta implementation.
Fields
rosetta_version: StringThe rosetta_version is the version of the Rosetta interface the implementation adheres to. This can be useful for clients looking to reliably parse responses.
node_version: StringThe node_version is the canonical version of the node runtime. This can help clients manage deployments.
middleware_version: Option<String>When a middleware server is used to adhere to the Rosetta interface, it should return its version here. This can help clients manage deployments.
metadata: Option<Value>Any other information that may be useful about versioning of dependent services should be returned here.
Implementations