Structs
- Construction
Parse Response - ConstructionParseResponse : ConstructionParseResponse contains an array of operations that occur in a transaction blob. This should match the array of operations provided to
/construction/preprocessand/construction/payloads.